test suite reviews and discussions
 help / color / mirror / Atom feed
From: Yinan <yinan.wang@intel.com>
To: dts@dpdk.org
Cc: Wang Yinan <yinan.wang@intel.com>
Subject: [dts] [PATCH v1] tests: update test commonds for vectorized cases in TestSuite_pvp_multi_paths_virtio_single_core_performance.py
Date: Wed, 29 Apr 2020 22:10:21 +0000	[thread overview]
Message-ID: <20200429221021.27727-1-yinan.wang@intel.com> (raw)

From: Wang Yinan <yinan.wang@intel.com>

Signed-off-by: Wang Yinan <yinan.wang@intel.com>
---
 ...i_paths_virtio_single_core_performance.cfg |  2 +-
 ...ti_paths_virtio_single_core_performance.py | 31 ++++++++++++++-----
 2 files changed, 24 insertions(+), 9 deletions(-)

diff --git a/conf/pvp_multi_paths_virtio_single_core_performance.cfg b/conf/pvp_multi_paths_virtio_single_core_performance.cfg
index f7703a3..ae25ed3 100644
--- a/conf/pvp_multi_paths_virtio_single_core_performance.cfg
+++ b/conf/pvp_multi_paths_virtio_single_core_performance.cfg
@@ -3,4 +3,4 @@ update_expected = True
 test_parameters = {64: [1024], 1518: [1024]}
 test_duration = 60
 accepted_tolerance = 2
-expected_throughput = {'test_perf_virtio_single_core_virtio11_mergeable': {64: {1024: 0.0}, 1518: {1024: 0.0}}, 'test_perf_virtio_single_core_virtio11_normal': {64: {1024: 0.0}, 1518: {1024: 0.0}}, 'test_perf_virtio_single_core_virtio11_inorder_mergeable': {64: {1024: 0.0}, 1518: {1024: 0.0}}, 'test_perf_virtio_single_core_virtio11_inorder_normal': {64: {1024: 0.0}, 1518: {1024: 0.0}}, 'test_perf_virtio_single_core_inorder_mergeable': {64: {1024: 0.0}, 1518: {1024: 0.0}}, 'test_perf_virtio_single_core_inorder_no_mergeable': {64: {1024: 0.0}, 1518: {1024: 0.0}}, 'test_perf_virtio_single_core_mergeable': {64: {1024: 0.0}, 1518: {1024: 0.0}}, 'test_perf_virtio_single_core_normal': {64: {1024: 0.0}, 1518: {1024: 0.0}}, 'test_perf_virtio_single_core_vector_rx': {64: {1024: 0.0}, 1518: {1024: 0.0}}}
+expected_throughput = {'test_perf_virtio_single_core_virtio11_vectorized': {64: {1024: 0.00}, 1518: {1024: 0.00}},'test_perf_virtio_single_core_virtio11_inorder_normal': {64: {1024: 0.00}, 1518: {1024: 0.00}},'test_perf_virtio_single_core_virtio11_mergeable': {64: {1024: 0.0}, 1518: {1024: 0.0}}, 'test_perf_virtio_single_core_virtio11_normal': {64: {1024: 0.0}, 1518: {1024: 0.0}}, 'test_perf_virtio_single_core_virtio11_inorder_mergeable': {64: {1024: 0.0}, 1518: {1024: 0.0}}, 'test_perf_virtio_single_core_virtio11_inorder_normal': {64: {1024: 0.0}, 1518: {1024: 0.0}}, 'test_perf_virtio_single_core_inorder_mergeable': {64: {1024: 0.0}, 1518: {1024: 0.0}}, 'test_perf_virtio_single_core_inorder_normal': {64: {1024: 0.0}, 1518: {1024: 0.0}}, 'test_perf_virtio_single_core_mergeable': {64: {1024: 0.0}, 1518: {1024: 0.0}}, 'test_perf_virtio_single_core_normal': {64: {1024: 0.0}, 1518: {1024: 0.0}}, 'test_perf_virtio_single_core_vector_rx': {64: {1024: 0.0}, 1518: {1024: 0.0}}}
diff --git a/tests/TestSuite_pvp_multi_paths_virtio_single_core_performance.py b/tests/TestSuite_pvp_multi_paths_virtio_single_core_performance.py
index ccf14fc..b98048b 100644
--- a/tests/TestSuite_pvp_multi_paths_virtio_single_core_performance.py
+++ b/tests/TestSuite_pvp_multi_paths_virtio_single_core_performance.py
@@ -115,11 +115,9 @@ class TestPVPMultiPathVirtioPerformance(TestCase):
                 self.dut_ports[0])
             destination_mac = self.dut.get_mac_address(
                 self.dut_ports[0])
-
             pkt = Packet(pkt_type='UDP', pkt_len=frame_size)
             pkt.config_layer('ether', {'dst': '%s' % destination_mac})
             pkt.save_pcapfile(self.tester, "%s/multi_path.pcap" % (self.out_path))
-
             tgen_input.append((tx_port, rx_port, "%s/multi_path.pcap" % (self.out_path)))
 
             self.tester.pktgen.clear_streams()
@@ -342,8 +340,25 @@ class TestPVPMultiPathVirtioPerformance(TestCase):
         """
         self.test_target = self.running_case
         self.expected_throughput = self.get_suite_cfg()['expected_throughput'][self.test_target]
-        virtio_pmd_arg = {"version": "packed_vq=1,in_order=1,mrg_rxbuf=0",
-                          "path": "--tx-offloads=0x0 --enable-hw-vlan-strip"}
+        virtio_pmd_arg = {"version": "packed_vq=1,in_order=1,mrg_rxbuf=0,vectorized=0",
+                          "path": "--enable-hw-vlan-strip"}
+        self.start_vhost_testpmd()
+        self.start_virtio_testpmd(virtio_pmd_arg)
+        self.send_and_verify("virtio_1.1_inorder_normal")
+        self.close_all_testpmd()
+        self.logger.info('result of all framesize result')
+        self.result_table_print()
+        self.handle_expected()
+        self.handle_results()
+
+    def test_perf_virtio_single_core_virtio11_vectorized(self):
+        """
+        performance for Vhost PVP virtio1.1 vectorized Path.
+        """
+        self.test_target = self.running_case
+        self.expected_throughput = self.get_suite_cfg()['expected_throughput'][self.test_target]
+        virtio_pmd_arg = {"version": "packed_vq=1,in_order=1,mrg_rxbuf=0,vectorized=1",
+                          "path": "--enable-hw-vlan-strip"}
         self.start_vhost_testpmd()
         self.start_virtio_testpmd(virtio_pmd_arg)
         self.send_and_verify("virtio_1.1_inorder_normal")
@@ -370,9 +385,9 @@ class TestPVPMultiPathVirtioPerformance(TestCase):
         self.handle_expected()
         self.handle_results()
 
-    def test_perf_virtio_single_core_inorder_no_mergeable(self):
+    def test_perf_virtio_single_core_inorder_normal(self):
         """
         performance for Vhost PVP In_order no_mergeable Path.
         """
         self.test_target = self.running_case
         self.expected_throughput = self.get_suite_cfg()['expected_throughput'][self.test_target]
@@ -410,7 +425,7 @@ class TestPVPMultiPathVirtioPerformance(TestCase):
         """
         self.test_target = self.running_case
         self.expected_throughput = self.get_suite_cfg()['expected_throughput'][self.test_target]
-        virtio_pmd_arg = {"version": "packed_vq=0,in_order=0,mrg_rxbuf=0",
+        virtio_pmd_arg = {"version": "packed_vq=0,in_order=0,mrg_rxbuf=0,vectorized=1",
                           "path": "--tx-offloads=0x0 --enable-hw-vlan-strip"}
         self.start_vhost_testpmd()
         self.start_virtio_testpmd(virtio_pmd_arg)
@@ -427,7 +442,7 @@ class TestPVPMultiPathVirtioPerformance(TestCase):
         """
         self.test_target = self.running_case
         self.expected_throughput = self.get_suite_cfg()['expected_throughput'][self.test_target]
-        virtio_pmd_arg = {"version": "packed_vq=0,in_order=0,mrg_rxbuf=0",
+        virtio_pmd_arg = {"version": "packed_vq=0,in_order=0,mrg_rxbuf=0,vectorized=1",
                           "path": "--tx-offloads=0x0"}
         self.start_vhost_testpmd()
         self.start_virtio_testpmd(virtio_pmd_arg)
@@ -370,9 +385,9 @@ class TestPVPMultiPathVirtioPerformance(TestCase):
         """
-        performance for Vhost PVP In_order no_mergeable Path.
+        performance for Vhost PVP In_order normal Path.
         """
         self.test_target = self.running_case
-- 
2.17.1


             reply	other threads:[~2020-04-30  5:16 UTC|newest]

Thread overview: 2+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2020-04-29 22:10 Yinan [this message]
2020-05-06  3:25 ` Tu, Lijuan

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=20200429221021.27727-1-yinan.wang@intel.com \
    --to=yinan.wang@intel.com \
    --cc=dts@dpdk.org \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for NNTP newsgroup(s).